..
    This file is part of Invenio.
    Copyright (C) 2019 CERN.
    Copyright (C) 2019 Northwestern University.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


Contributors
============

- Guillaume Viger
- Pablo Panero
